Image sources
=============

Images are drawn by `draw.io`_ . To edit images, open `draw.io`_,
select *Open Existing Diagram* and chose the *\*.xml* file under this
directory.

.. _draw.io: <https://www.draw.io/>
